aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/assets
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/assets')
-rw-r--r--phpBB/assets/javascript/core.js74
1 files changed, 37 insertions, 37 deletions
diff --git a/phpBB/assets/javascript/core.js b/phpBB/assets/javascript/core.js
index 421d6a12dc..d4b98d3ee0 100644
--- a/phpBB/assets/javascript/core.js
+++ b/phpBB/assets/javascript/core.js
@@ -43,11 +43,11 @@ phpbb.loadingAlert = function() {
* Clear loading alert timeout
*/
phpbb.clearLoadingTimeout = function() {
- if (phpbbAlertTimer != null) {
+ if (phpbbAlertTimer !== null) {
clearTimeout(phpbbAlertTimer);
phpbbAlertTimer = null;
}
-}
+};
/**
* Display a simple alert similar to JSs native alert().
@@ -135,13 +135,13 @@ phpbb.confirm = function(msg, callback, fadedark) {
e.stopPropagation();
});
- var click_handler = function(e) {
+ var clickHandler = function(e) {
var res = this.className === 'button1';
var fade = (typeof fadedark !== 'undefined' && !fadedark && res) ? div : dark;
fade.fadeOut(phpbb.alertTime, function() {
div.hide();
});
- div.find('input[type="button"]').unbind('click', click_handler);
+ div.find('input[type="button"]').unbind('click', clickHandler);
callback(res);
if (e) {
@@ -149,7 +149,7 @@ phpbb.confirm = function(msg, callback, fadedark) {
e.stopPropagation();
}
};
- div.find('input[type="button"]').one('click', click_handler);
+ div.find('input[type="button"]').one('click', clickHandler);
dark.one('click', function(e) {
div.find('.alert_close').unbind('click');
@@ -207,7 +207,7 @@ phpbb.confirm = function(msg, callback, fadedark) {
* @argument string string The querystring to parse.
* @returns object The object created.
*/
-phpbb.parse_querystring = function(string) {
+phpbb.parseQuerystring = function(string) {
var params = {}, i, split;
string = string.split('&');
@@ -386,9 +386,9 @@ phpbb.ajaxify = function(options) {
/**
* Hide the optgroups that are not the selected timezone
*
* @param bool keep_selection Shall we keep the value selected, or shall the user be forced to repick one.
*/
-phpbb.timezone_switch_date = function(keep_selection) {
+phpbb.timezoneSwitchDate = function(keepSelection) {
if ($('#timezone_copy').length == 0) {
// We make a backup of the original dropdown, so we can remove optgroups
// instead of setting display to none, because IE and chrome will not
@@ -412,30 +412,30 @@ phpbb.timezone_switch_date = function(keep_selection) {
if ($("#timezone > optgroup[label='" + $('#tz_date').val() + "'] > option").size() == 1) {
// If there is only one timezone for the selected date, we just select that automatically.
$("#timezone > optgroup[label='" + $('#tz_date').val() + "'] > option:first").attr('selected', true);
- keep_selection = true;
+ keepSelection = true;
}
- if (typeof keep_selection !== 'undefined' && !keep_selection) {
+ if (typeof keepSelection !== 'undefined' && !keepSelection) {
var timezoneOptions = $('#timezone > optgroup option');
if (timezoneOptions.filter(':selected').length <= 0) {
timezoneOptions.filter(':first').attr('selected', true);
}
}
-}
+};
/**
* Display the date/time select
*/
-phpbb.timezone_enable_date_selection = function() {
+phpbb.timezoneEnableDateSelection = function() {
$('#tz_select_date').css('display', 'block');
-}
+};
/**
* Preselect a date/time or suggest one, if it is not picked.
*
* @param bool force_selector Shall we select the suggestion?
*/
-phpbb.timezone_preselect_select = function(force_selector) {
+phpbb.timezonePreselectSelect = function(forceSelector) {
// The offset returned here is in minutes and negated.
// http://www.w3schools.com/jsref/jsref_getTimezoneOffset.asp
@@ -464,21 +464,21 @@ phpbb.timezone_preselect_select = function(force_selector) {
}
var prefix = 'GMT' + sign + hours + ':' + minutes;
- var prefix_length = prefix.length;
- var selector_options = $('#tz_date > option');
+ var prefixLength = prefix.length;
+ var selectorOptions = $('#tz_date > option');
- for (var i = 0; i < selector_options.length; ++i) {
- var option = selector_options[i];
+ for (var i = 0; i < selectorOptions.length; ++i) {
+ var option = selectorOptions[i];
- if (option.value.substring(0, prefix_length) == prefix) {
- if ($('#tz_date').val() != option.value && !force_selector) {
+ if (option.value.substring(0, prefixLength) == prefix) {
+ if ($('#tz_date').val() != option.value && !forceSelector) {
// We do not select the option for the user, but notify him,
// that we would suggest a different setting.
- phpbb.timezone_switch_date(true);
+ phpbb.timezoneSwitchDate(true);
$('#tz_select_date_suggest').css('display', 'inline');
} else {
option.selected = true;
- phpbb.timezone_switch_date(!force_selector);
+ phpbb.timezoneSwitchDate(!forceSelector);
$('#tz_select_date_suggest').css('display', 'none');
}
@@ -490,7 +490,7 @@ phpbb.timezone_preselect_select = function(force_selector) {
return;
}
}
-}
+};
phpbb.ajaxCallbacks = {};
@@ -502,7 +502,7 @@ phpbb.ajaxCallbacks = {};
* @param string id The name of the callback.
* @param function callback The callback to be called.
*/
-phpbb.add_ajax_callback = function(id, callback) {
+phpbb.addAjaxCallback = function(id, callback) {
if (typeof callback === 'function') {
phpbb.ajaxCallbacks[id] = callback;
}
@@ -515,7 +515,7 @@ phpbb.add_ajax_callback = function(id, callback) {
* the alt-text data attribute, and replaces the text in the attribute with the
* current text so that the process can be repeated.
*/
-phpbb.add_ajax_callback('alt_text', function() {
+phpbb.addAjaxCallback('alt_text', function() {
var el = $(this),
altText;
@@ -534,28 +534,28 @@ phpbb.add_ajax_callback('alt_text', function() {
* Additionally it replaces the class of the link's parent
* and changes the link itself.
*/
-phpbb.add_ajax_callback('toggle_link', function() {
+phpbb.addAjaxCallback('toggle_link', function() {
var el = $(this),
- toggle_text,
- toggle_url,
- toggle_class;
+ toggleText,
+ toggleUrl,
+ toggleClass;
// Toggle link text
- toggle_text = el.attr('data-toggle-text');
+ toggleText = el.attr('data-toggle-text');
el.attr('data-toggle-text', el.text());
- el.attr('title', toggle_text);
- el.text(toggle_text);
+ el.attr('title', toggleText);
+ el.text(toggleText);
// Toggle link url
- toggle_url = el.attr('data-toggle-url');
+ toggleUrl = el.attr('data-toggle-url');
el.attr('data-toggle-url', el.attr('href'));
- el.attr('href', toggle_url);
+ el.attr('href', toggleUrl);
// Toggle class of link parent
- toggle_class = el.attr('data-toggle-class');
+ toggleClass = el.attr('data-toggle-class');
el.attr('data-toggle-class', el.parent().attr('class'));
- el.parent().attr('class', toggle_class);
+ el.parent().attr('class', toggleClass);
});
})(jQuery); // Avoid conflicts with other libraries
@@ -386,9 +386,9 @@ phpbb.ajaxify = function(options) {
* Hide the optgroups that are not the selected timezone
*
-* @param bool keep_selection Shall we keep the value selected, or shall the user be forced to repick one.
+* @param bool keepSelection Shall we keep the value selected, or shall the user be forced to repick one.
*/
@@ -412,30 +412,30 @@ phpbb.timezone_switch_date = function(keep_selection) {
* Preselect a date/time or suggest one, if it is not picked.
*
-* @param bool force_selector Shall we select the suggestion?
+* @param bool forceSelector Shall we select the suggestion?
*/